@@ -1,3 +1,6 @@
+import logging
+
+
 class Counter:
     def __init__(self, label):
 
@@ -6,8 +9,8 @@ class Counter:
         self.count = 0
 
     def __str__(self):
-        #return f'{self.label}: {self.count} of {self.total}'
         return f'progress: {(self.count * 100) // self.total}%'
 
     def increment(self):
         self.count += 1
+        logging.debug(str(self))
\ No newline at end of file
